==> kadaster-gds2-1.2-sources.jar: nl/kadaster/schemas/generiek_extern/procesresultaat/v20110922/ProcesVerwerking.java <==

package nl.kadaster.schemas.generiek_extern.procesresultaat.v20110922;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for ProcesVerwerking complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="ProcesVerwerking">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://www.kadaster.nl/schemas/generiek-extern/procesresultaat/v20110922}ProcesVerwerkingCode"/>
 *         &lt;element ref="{http://www.kadaster.nl/schemas/generiek-extern/procesresultaat/v20110922}SeverityCode"/>
 *         &lt;element ref="{http://www.kadaster.nl/schemas/generiek-extern/procesresultaat/v20110922}Melding" maxOccurs="unbounded" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ProcesVerwerking", propOrder = {
    "procesVerwerkingCode",
    "severityCode",
    "melding"
})
public class ProcesVerwerking {

    @XmlElement(name = "ProcesVerwerkingCode", required = true, defaultValue = "1")
    protected String procesVerwerkingCode;
    @XmlElement(name = "SeverityCode", required = true, defaultValue = "INFO")
    protected String severityCode;
    @XmlElement(name = "Melding")
    protected List<Melding> melding;

    /**
     * Gets the value of the procesVerwerkingCode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getProcesVerwerkingCode() {
        return procesVerwerkingCode;
    }

    /**
     * Sets the value of the procesVerwerkingCode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setProcesVerwerkingCode(String value) {
        this.procesVerwerkingCode = value;
    }

    /**
     * Dit element is een bouwsteen, welke gebruikt kan worden om de ernst van een fout aan te geven. De standaard classificaties worden gebruikt (in aflopende volgorde van ernst): SECURITY, FATAL, ERROR, WARNING, INFO. De default is INFO.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSeverityCode() {
        return severityCode;
    }

    /**
     * Sets the value of the severityCode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSeverityCode(String value) {
        this.severityCode = value;
    }

    /**
     * Dit element is een bouwsteen, welke gebruikt kan worden om een melding, in het bijzonder een foutmelding, terug te koppelen. Gets the value of the melding property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the melding property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getMelding().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Melding }
     * 
     * 
     */
    public List<Melding> getMelding() {
        if (melding == null) {
            melding = new ArrayList<Melding>();
        }
        return this.melding;
    }

}

==> kadaster-gds2-2.5-sources.jar: nl/kadaster/schemas/generiek_extern/procesresultaat/v20110922/ProcesVerwerking.java <==

package nl.kadaster.schemas.generiek_extern.procesresultaat.v20110922;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * &lt;p&gt;Java class for ProcesVerwerking complex type.
 * 
 * &lt;p&gt;The following schema fragment specifies the expected content contained within this class.
 * 
 * &lt;pre&gt;
 * &amp;lt;complexType name="ProcesVerwerking"&amp;gt;
 *   &amp;lt;complexContent&amp;gt;
 *     &amp;lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&amp;gt;
 *       &amp;lt;sequence&amp;gt;
 *         &amp;lt;element ref="{http://www.kadaster.nl/schemas/generiek-extern/procesresultaat/v20110922}ProcesVerwerkingCode"/&amp;gt;
 *         &amp;lt;element ref="{http://www.kadaster.nl/schemas/generiek-extern/procesresultaat/v20110922}SeverityCode"/&amp;gt;
 *         &amp;lt;element ref="{http://www.kadaster.nl/schemas/generiek-extern/procesresultaat/v20110922}Melding" maxOccurs="unbounded" minOccurs="0"/&amp;gt;
 *       &amp;lt;/sequence&amp;gt;
 *     &amp;lt;/restriction&amp;gt;
 *   &amp;lt;/complexContent&amp;gt;
 * &amp;lt;/complexType&amp;gt;
 * &lt;/pre&gt;
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ProcesVerwerking", propOrder = {
    "procesVerwerkingCode",
    "severityCode",
    "melding"
})
public class ProcesVerwerking {

    @XmlElement(name = "ProcesVerwerkingCode", required = true, defaultValue = "1")
    protected String procesVerwerkingCode;
    @XmlElement(name = "SeverityCode", required = true, defaultValue = "INFO")
    protected String severityCode;
    @XmlElement(name = "Melding")
    protected List<Melding> melding;

    /**
     * Gets the value of the procesVerwerkingCode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getProcesVerwerkingCode() {
        return procesVerwerkingCode;
    }

    /**
     * Sets the value of the procesVerwerkingCode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setProcesVerwerkingCode(String value) {
        this.procesVerwerkingCode = value;
    }

    /**
     * Dit element is een bouwsteen, welke gebruikt kan worden om de ernst van een fout aan te geven. De standaard classificaties worden gebruikt (in aflopende volgorde van ernst): SECURITY, FATAL, ERROR, WARNING, INFO. De default is INFO.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSeverityCode() {
        return severityCode;
    }

    /**
     * Sets the value of the severityCode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSeverityCode(String value) {
        this.severityCode = value;
    }

    /**
     * Dit element is een bouwsteen, welke gebruikt kan worden om een melding, in het bijzonder een foutmelding, terug te koppelen. Gets the value of the melding property.
     * 
     * &lt;p&gt;
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a &lt;CODE&gt;set&lt;/CODE&gt; method for the melding property.
     * 
     * &lt;p&gt;
     * For example, to add a new item, do as follows:
     * &lt;pre&gt;
     *    getMelding().add(newItem);
     * &lt;/pre&gt;
     * 
     * 
     * &lt;p&gt;
     * Objects of the following type(s) are allowed in the list
     * {@link Melding }
     * 
     * 
     */
    public List<Melding> getMelding() {
        if (melding == null) {
            melding = new ArrayList<Melding>();
        }
        return this.melding;
    }

}
